Remove warning on ballot/any/all and pop/clz.

Since these are supported in HIP no reason to emit warnings.
This commit is contained in:
Ben Sander
2016-02-02 10:02:48 -06:00
szülő 1e2fb8a1ab
commit 3898f6af3c
3 fájl változott, egészen pontosan 29 új sor hozzáadva és 5 régi sor törölve
+13
Fájl megtekintése
@@ -75,6 +75,7 @@ macro (make_hip_executable exe cpp)
endif()
endmacro()
macro (make_test exe )
string (REPLACE " " "" smush_args ${ARGN})
set (testname ${exe}${smush_args}.tst)
@@ -87,6 +88,16 @@ macro (make_test exe )
endmacro()
macro (make_hipify_test sourceFile )
#string (REPLACE " " "" smush_args ${ARGN})
set (testname ${sourceFile}${smush_args}.tst)
add_test (NAME ${testname}
COMMAND ${HIP_PATH}/bin/hipify ${PROJECT_SOURCE_DIR}/${sourceFile} ${ARGN}
)
endmacro()
macro (make_test_matches exe match_string)
string (REPLACE " " "" smush_args ${ARGN})
set (testname ${exe}${smush_args}.tst)
@@ -133,3 +144,5 @@ make_test(hipGridLaunch " " )
make_test(hipMemcpy " " )
make_test(hipHcc " " )
make_hipify_test(specialFunc.cu )
+11
Fájl megtekintése
@@ -0,0 +1,11 @@
//Test to ensure hipify runs correctly.
// Hipify may report warnings for some missing/unsupported functions
void __global__
test_kernel(float *A)
{
int tid = blockIdx.x * blockDim.x + threadIdx.x;
float a = __ballot(tid < 16);
float b = __shfl(tid < 16);
}